@@ -1,5 +1,5 @@
 from typing import List, Tuple
-from tc2 import CommandType, tc2lib, TC2Observation
+from tc2 import CommandType, tc2lib
 from tc2.tools import *
 from tc2.constants import *
 
@@ -8,7 +8,7 @@ def do_nothing(tcstate: tc2lib.State) -> List[CommandType]:
     raise TypeError(f"tcstate argument should be of type tc2lib.State, got {tcstate}")
   return []
   
-def our_units(tcstate: tc2lib.State) -> List[CommandType]:
+def our_units(tcstate: tc2lib.State) -> List[tc2lib.Unit]:
   if not isinstance(tcstate, tc2lib.State):
     raise TypeError(f"tcstate argument should be of type tc2lib.State, got {tcstate}")
   player = tcstate.player_id
